Package: muRL
Type: Package
Title: Mailmerge using R, LaTeX, and the Web
Version: 0.1-13
Date: 2023-08-21
Author: Ryan T. Moore <rtm@american.edu> and Andrew Reeves <reeves@wustl.edu>
Maintainer: Ryan T. Moore <rtm@american.edu>
Depends: utils, maps, stringr
Imports: graphics
Description: Provides mailmerge methods for reading spreadsheets of addresses and other relevant information to create standardized but customizable letters.  Provides a method for mapping US ZIP codes, including those of letter recipients.  Provides a method for parsing and processing html code from online job postings of the American Political Science Association.
License: GPL-3 | file LICENSE
URL: https://www.ryantmoore.org/software.murl.html
LazyLoad: yes
Packaged: 2023-08-21 23:23:23 UTC; rtm
NeedsCompilation: no
Repository: CRAN
Date/Publication: 2023-08-22 06:40:02 UTC
Built: R 4.6.0; ; 2026-04-28 07:20:39 UTC; unix
