# muRL
Mailmerge using R, LaTeX, and the Web

The current CRAN version of `muRL` is 0-1.12 (2019-12-05).  The first version of 0.1-13 is compiled and the `.tar.gz` is visible in the `master` branch.  If you are working on this package and wish to create a branch on which to make your changes, make the new branch name short, grouped, and descriptive.
